@@ -1,4 +1,4 @@
-import jam.common as common
+from .common import consts
 
 # Client events
 
@@ -8,11 +8,11 @@ task_client_events = \
         'on_view_form_created': 'item',
         'on_edit_form_created': 'item',
         'on_filter_form_created': 'item',
-        'on_param_form_created': 'item',
+        'on_param_form_created': 'report',
         'on_view_form_shown': 'item',
         'on_edit_form_shown': 'item',
         'on_filter_form_shown': 'item',
-        'on_param_form_shown': 'item',
+        'on_param_form_shown': 'report',
         'on_view_form_close_query': 'item',
         'on_edit_form_close_query': 'item',
         'on_filter_form_close_query': 'item',
@@ -20,7 +20,7 @@ task_client_events = \
         'on_view_form_closed': 'item',
         'on_edit_form_closed': 'item',
         'on_filter_form_closed': 'item',
-        'on_param_form_closed': 'item',
+        'on_param_form_closed': 'report',
         'on_view_form_keyup': 'item, event',
         'on_view_form_keydown': 'item, event',
         'on_edit_form_keyup': 'item, event',
@@ -39,6 +39,10 @@ group_client_events = \
         'on_view_form_close_query': 'item',
         'on_edit_form_close_query': 'item',
         'on_filter_form_close_query': 'item',
+        'on_view_form_closed': 'item',
+        'on_edit_form_closed': 'item',
+        'on_filter_form_closed': 'item',
+        'on_param_form_closed': 'report',
         'on_view_form_keyup': 'item, event',
         'on_view_form_keydown': 'item, event',
         'on_edit_form_keyup': 'item, event',
@@ -47,9 +51,10 @@ group_client_events = \
 
 reports_client_events = \
     {
-        'on_param_form_created': 'item',
-        'on_param_form_shown': 'item',
+        'on_param_form_created': 'report',
+        'on_param_form_shown': 'report',
         'on_param_form_close_query': 'report',
+        'on_param_form_closed': 'report',
         'on_open_report': 'report, url',
         'on_before_print_report': 'report'
     }
@@ -64,6 +69,10 @@ detail_client_events = \
         'on_filter_form_shown': 'item',
         'on_view_form_close_query': 'item',
         'on_edit_form_close_query': 'item',
+        'on_filter_form_close_query': 'item',
+        'on_view_form_closed': 'item',
+        'on_edit_form_closed': 'item',
+        'on_filter_form_closed': 'item',
         'on_view_form_keyup': 'item, event',
         'on_view_form_keydown': 'item, event',
         'on_edit_form_keyup': 'item, event',
@@ -91,17 +100,19 @@ detail_client_events = \
         'on_filter_changed': 'filter',
         'on_filter_select_value': 'field, lookup_item',
         'on_field_validate': 'field',
-        'on_field_get_text': 'field'
+        'on_field_get_text': 'field',
+        'on_field_get_html': 'field'
     }
 
 item_client_events = detail_client_events
-item_client_events['on_before_apply'] = 'item'
+item_client_events['on_before_apply'] = 'item, params'
 item_client_events['on_after_apply'] = 'item'
+item_client_events['on_detail_changed'] = 'item, detail'
 
 report_client_events = \
     {
-        'on_param_form_created': 'item',
-        'on_param_form_shown': 'item',
+        'on_param_form_created': 'report',
+        'on_param_form_shown': 'report',
         'on_param_form_close_query': 'report',
         'on_before_print_report': 'report',
         'on_open_report': 'report, url',
@@ -113,13 +124,10 @@ report_client_events = \
 task_server_events = \
     {
         'on_created': 'task',
+        'on_login': 'task, form_data, info',
         'on_open': 'item, params',
-        'on_count': 'item, params',
-        'on_apply': 'item, delta, params'
-
-        #~ 'on_login': 'task, login, password_hash, env',
-        #~ 'on_ext_request': 'task, request, params',
-        #~ 'on_request': 'task, user_info, env, request, item, params, ext'
+        'on_apply': 'item, delta, params, connection',
+        'on_ext_request': 'task, request, params'
     }
 
 group_server_events = \
@@ -133,13 +141,11 @@ reports_server_events = \
 
 detail_server_events = \
     {
-        'on_open': 'item, params',
-        'on_count': 'item, params',
-#        'on_field_get_text': 'field'
+        'on_open': 'item, params'
     }
 
 item_server_events = detail_server_events
-item_server_events['on_apply'] = 'item, delta, params'
+item_server_events['on_apply'] = 'item, delta, params, connection'
 
 report_server_events = \
     {
@@ -151,30 +157,30 @@ report_server_events = \
 
 def get_events(item_type_id, server):
     if server:
-        if item_type_id == common.TASK_TYPE:
+        if item_type_id == consts.TASK_TYPE:
             return task_server_events
-        elif item_type_id in [common.ITEMS_TYPE, common.TABLES_TYPE]:
+        elif item_type_id in [consts.ITEMS_TYPE, consts.TABLES_TYPE]:
             return group_server_events
-        elif item_type_id == common.REPORTS_TYPE:
+        elif item_type_id == consts.REPORTS_TYPE:
             return reports_server_events
-        elif item_type_id in [common.ITEM_TYPE, common.TABLE_TYPE, common.DETAIL_TYPE]:
+        elif item_type_id in [consts.ITEM_TYPE, consts.TABLE_TYPE, consts.DETAIL_TYPE]:
             return item_server_events
-        elif item_type_id == common.REPORT_TYPE:
+        elif item_type_id == consts.REPORT_TYPE:
             return report_server_events
-        elif item_type_id == common.DETAIL_TYPE:
+        elif item_type_id == consts.DETAIL_TYPE:
             return detail_server_events
     else:
-        if item_type_id == common.TASK_TYPE:
+        if item_type_id == consts.TASK_TYPE:
             return task_client_events
-        elif item_type_id in [common.ITEMS_TYPE, common.TABLES_TYPE]:
+        elif item_type_id in [consts.ITEMS_TYPE, consts.TABLES_TYPE]:
             return group_client_events
-        elif item_type_id == common.REPORTS_TYPE:
+        elif item_type_id == consts.REPORTS_TYPE:
             return reports_client_events
-        elif item_type_id in [common.ITEM_TYPE, common.TABLE_TYPE, common.DETAIL_TYPE]:
+        elif item_type_id in [consts.ITEM_TYPE, consts.TABLE_TYPE, consts.DETAIL_TYPE]:
             return item_client_events
-        elif item_type_id == common.REPORT_TYPE:
+        elif item_type_id == consts.REPORT_TYPE:
             return report_client_events
-        elif item_type_id == common.DETAIL_TYPE:
+        elif item_type_id == consts.DETAIL_TYPE:
             return detail_client_events
 
 
